@@ -1,6 +1,7 @@
 import { ChangeDetectionStrategy, Component } from "@angular/core";
 import { HeaderService } from "@synerty/peek-plugin-base-js";
 import { configLinks } from "@_peek/plugin-config-links";
+import { peekAppEnvironment } from "../../../environments/peek-app-environment";
 
 @Component({
     selector: "config-page",
@@ -9,6 +10,8 @@ import { configLinks } from "@_peek/plugin-config-links";
     changeDetection: ChangeDetectionStrategy.OnPush,
 })
 export class ConfigPage {
+    readonly appVersion: string = peekAppEnvironment.version;
+
     configLinks = configLinks;
 
     constructor(public headerService: HeaderService) {
